@@ -12,9 +12,6 @@ function(lon,lat,code_epsg,taille_rond_m)
     #On cree le grand cercle en pl
     ronds_pl_leg_1 <- st_buffer(ronds_pl_leg, taille_rond_m)
 
-    #que l'on convertit en WGS84
-    ronds_sf_leg_1 <- st_transform(ronds_pl_leg_1,crs=4326)
-
     #On cree le petit cercle en pl
     ronds_pl_leg_2 <- st_buffer(ronds_pl_leg, taille_rond_m/sqrt(3))
 
@@ -25,13 +22,7 @@ function(lon,lat,code_epsg,taille_rond_m)
     ronds_pl_leg <- rbind(ronds_pl_leg_1,ronds_pl_leg_3)
 
     #On convertit le petit cercle en WGS84
-    ronds_sf_leg_2 <- st_transform(ronds_pl_leg_2,crs=4326)
-
-    #que l'on decale sur le grand cercle
-    ronds_sf_leg_3 <- st_sf(geometry=st_sfc(st_geometry(ronds_sf_leg_2)+c(0,(st_bbox(ronds_sf_leg_1)[2]-st_bbox(ronds_sf_leg_2)[2])),crs=4326))
-
-    #On fusionne les 2 cercles en WGS84
-    ronds_sf_leg <- rbind(ronds_sf_leg_1,ronds_sf_leg_3)
-
+    ronds_sf_leg <- st_transform(ronds_pl_leg,crs=4326)
+    
     return(list(ronds_sf_leg,ronds_pl_leg))
   }
