@@ -3,8 +3,8 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
   {
     options("stringsAsFactors"=FALSE)
 
-    # Verification des parametres
-
+	# Verification des parametres
+	
     msg_error1<-msg_error2<-msg_error3<-msg_error4<-msg_error5<-msg_error6<-msg_error7<-msg_error8<-msg_error9<-msg_error10<-msg_error11<-msg_error12<-msg_error13<-msg_error14<-msg_error15<-msg_error16<-msg_error17<-msg_error18<-msg_error19<-msg_error20<-msg_error21<-msg_error22<-msg_error23<-msg_error24<-msg_error25<-msg_error26<-msg_error27<-msg_error28<-msg_error29<-msg_error30<-msg_error31 <- NULL
 
     if(any(class(data)!="data.frame")) msg_error1 <- "Les donnees doivent etre dans un data.frame / "
@@ -73,7 +73,9 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
       {
         names(fondSousAnalyse[[i]])[1] <- "CODE"
         names(fondSousAnalyse[[i]])[2] <- "LIBELLE"
-        fondSousAnalyse[[i]]$LIBELLE<-iconv(fondSousAnalyse[[i]]$LIBELLE,"latin1","utf8")
+        if(any(Encoding(fondSousAnalyse[[i]]$LIBELLE) %in% "latin1")){
+          fondSousAnalyse[[i]]$LIBELLE<-iconv(fondSousAnalyse[[i]]$LIBELLE,"latin1","UTF-8")
+        }
       }
     }
     if(!is.null(fondSurAnalyse))
@@ -82,21 +84,31 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
       {
         names(fondSurAnalyse[[i]])[1] <- "CODE"
         names(fondSurAnalyse[[i]])[2] <- "LIBELLE"
-        fondSurAnalyse[[i]]$LIBELLE<-iconv(fondSurAnalyse[[i]]$LIBELLE,"latin1","utf8")
+        if(any(Encoding(fondSurAnalyse[[i]]$LIBELLE) %in% "latin1")){
+          fondSurAnalyse[[i]]$LIBELLE<-iconv(fondSurAnalyse[[i]]$LIBELLE,"latin1","UTF-8")
+        }
       }
     }
-    fondMaille$LIBELLE<-iconv(fondMaille$LIBELLE,"latin1","utf8")
+    if(any(Encoding(fondMaille$LIBELLE) %in% "latin1")){
+      fondMaille$LIBELLE<-iconv(fondMaille$LIBELLE,"latin1","UTF-8")
+    }
     if(titreLeg!="")
     {
-      titreLeg<-iconv(titreLeg,"latin1","utf8")
+      if(any(Encoding(titreLeg) %in% "latin1")){
+        titreLeg<-iconv(titreLeg,"latin1","UTF-8")
+      }
     }
     if(titreCarte!="")
     {
-      titreCarte<-iconv(titreCarte,"latin1","utf8")
+      if(any(Encoding(titreCarte) %in% "latin1")){
+        titreCarte<-iconv(titreCarte,"latin1","UTF-8")
+      }
     }
     if(sourceCarte!="")
     {
-      sourceCarte<-iconv(sourceCarte,"latin1","utf8")
+      if(any(Encoding(sourceCarte) %in% "latin1")){
+        sourceCarte<-iconv(sourceCarte,"latin1","UTF-8")
+      }
     }
 
     code_epsg <- switch(emprise, #emprise
