@@ -6,9 +6,5 @@ function()
   # import de l'objet sf
   paysm <- st_read(dsn = path_to_shp, quiet = TRUE)
   
-  st_crs(paysm)$input <- 102110
-  
-  paysm <- st_transform(paysm, crs = 2154)
-  
 return(paysm)
 }
