@@ -6,9 +6,5 @@ function()
   # import de l'objet sf
   reg04 <- st_read(dsn = path_to_shp, quiet = TRUE)
   
-  st_crs(reg04)$input <- 7077
-  
-  reg04 <- st_transform(reg04, crs = 2975)
-  
 return(reg04)
 }
