@@ -6,9 +6,5 @@ function()
   # import de l'objet sf
   reg06 <- st_read(dsn = path_to_shp, quiet = TRUE)
   
-  st_crs(reg06)$input <- 7075
-  
-  reg06 <- st_transform(reg06, crs = 4471)
-  
 return(reg06)
 }
