@@ -82,7 +82,9 @@ function(data,fondMaille,typeMaille,fondContour,fondSuppl=NULL,idDataDepart,idDa
     {
       names(fondEtranger)[1] <- "CODE"
       names(fondEtranger)[2] <- "LIBGEO"
-      fondEtranger$LIBGEO<-iconv(fondEtranger$LIBGEO,"latin1","utf8")
+      if(any(Encoding(fondEtranger$LIBGEO) %in% "latin1")){
+        fondEtranger$LIBGEO<-iconv(fondEtranger$LIBGEO,"latin1","UTF-8")
+      }
 
       if(substr(st_crs(fondEtranger)[1]$input,1,5) == "EPSG:")
       {
@@ -101,11 +103,17 @@ function(data,fondMaille,typeMaille,fondContour,fondSuppl=NULL,idDataDepart,idDa
     {
       names(fondSuppl)[1] <- "CODE"
       names(fondSuppl)[2] <- "LIBELLE"
-      fondSuppl$LIBELLE<-iconv(fondSuppl$LIBELLE,"latin1","utf8")
+      if(any(Encoding(fondSuppl$LIBELLE) %in% "latin1")){
+        fondSuppl$LIBELLE<-iconv(fondSuppl$LIBELLE,"latin1","UTF-8")
+      }
     }
 
-    fondMaille$LIBELLE<-iconv(fondMaille$LIBELLE,"latin1","utf8")
-    fondContour$LIBELLE<-iconv(fondContour$LIBELLE,"latin1","utf8")
+    if(any(Encoding(fondMaille$LIBELLE) %in% "latin1")){
+      fondMaille$LIBELLE<-iconv(fondMaille$LIBELLE,"latin1","UTF-8")
+    }
+    if(any(Encoding(fondContour$LIBELLE) %in% "latin1")){
+      fondContour$LIBELLE<-iconv(fondContour$LIBELLE,"latin1","UTF-8")
+    }
 
     ui <- navbarPage("OCEANIS", id="menu",
 
